Stan Math Library: Eigen::NumTraits< stan::math::var > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Static Public Member Functions | List of all members
Eigen::NumTraits< stan::math::var > Struct Template Reference

Numerical traits template override for Eigen for automatic gradient variables. More...

`#include <Eigen_NumTraits.hpp>`

## Public Types
enum | { IsInteger = 0, IsSigned = 1, IsComplex = 0, RequireInitialization = 0, ReadCost = 1, AddCost = 1, MulCost = 1, HasFloatingPoint = 1 }
| Properties for automatic differentiation variables read by Eigen matrix library. More...
typedef stan::math::var | Real
| Real-valued variables. More...
typedef stan::math::var | NonInteger
| Non-integer valued variables. More...
typedef stan::math::var | Nested
| Nested variables. More...

## Static Public Member Functions
static Real | epsilon ()
| Return standard library's epsilon for double-precision floating point, `std::numeric_limits<double>::epsilon()`. More...
static Real | dummy_precision ()
| Return dummy precision. More...
static Real | highest ()
| Return standard library's highest for double-precision floating point, `std::numeric_limits<double>max()`. More...
static Real | lowest ()
| Return standard library's lowest for double-precision floating point, `&#45;std::numeric_limits<double>max()`. More...

## Detailed Description

### template<>
struct Eigen::NumTraits< stan::math::var >

Numerical traits template override for Eigen for automatic gradient variables.

Definition at line 16 of file Eigen_NumTraits.hpp.

## Member Typedef Documentation

typedef stan::math::var Eigen::NumTraits< stan::math::var >::Nested

Nested variables.

Required for numerical traits.

Definition at line 36 of file Eigen_NumTraits.hpp.

typedef stan::math::var Eigen::NumTraits< stan::math::var >::NonInteger

Non-integer valued variables.

Required for numerical traits.

Definition at line 29 of file Eigen_NumTraits.hpp.

typedef stan::math::var Eigen::NumTraits< stan::math::var >::Real

Real-valued variables.

Required for numerical traits.

Definition at line 22 of file Eigen_NumTraits.hpp.

## Member Enumeration Documentation

anonymous enum

Properties for automatic differentiation variables read by Eigen matrix library.

Enumerator
IsInteger |
IsSigned |
IsComplex |
RequireInitialization |
ReadCost |
AddCost |
MulCost |
HasFloatingPoint |

Definition at line 79 of file Eigen_NumTraits.hpp.

## Member Function Documentation

static Real Eigen::NumTraits< stan::math::var >::dummy_precision | ( |  | ) |
| inlinestatic

Return dummy precision.

Definition at line 51 of file Eigen_NumTraits.hpp.

static Real Eigen::NumTraits< stan::math::var >::epsilon | ( |  | ) |
| inlinestatic

Return standard library's epsilon for double-precision floating point, `std::numeric_limits<double>::epsilon()`.

Returns
  Same epsilon as a `double`.

Definition at line 44 of file Eigen_NumTraits.hpp.

static Real Eigen::NumTraits< stan::math::var >::highest | ( |  | ) |
| inlinestatic

Return standard library's highest for double-precision floating point, `std::numeric_limits<double>max()`.

Returns
  Same highest value as a `double`.

Definition at line 61 of file Eigen_NumTraits.hpp.

static Real Eigen::NumTraits< stan::math::var >::lowest | ( |  | ) |
| inlinestatic

Return standard library's lowest for double-precision floating point, `&#45;std::numeric_limits<double>max()`.

Returns
  Same lowest value as a `double`.

Definition at line 71 of file Eigen_NumTraits.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/mat/fun/Eigen_NumTraits.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.